import requests
import time
import inspect
import sys
from apscheduler.schedulers.background import BlockingScheduler 
import apscheduler.schedulers.background
from colorama import init
init()
from colorama import Fore, Back, Style
from .methods import message
import datetime
import sys
import os
import signal

class bot:
    def event(token):
     if token == None:
                   print(Fore.YELLOW+f"You did not specify a keyword (token = ...) in the 'event' decorator (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (token = ...) в декораторі 'event'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)
     def decorator_function(func):
        def wrapper_function():
            msg = message(token)
            if func.__name__ == 'update':
             if msg.message is None:
                 print(Fore.RED+f"""{datetime.datetime.now()} : Callback
                {msg.callback}"""+Style.RESET_ALL) 
                 func() 
                
             if msg.callback is  None:
                if msg.text is None:
                    pass
                else:
                 print(Fore.RED+f"""{datetime.datetime.now()} : Message 
                {msg.message}"""+Style.RESET_ALL) 
                
                 func() 
            else:
                func()
        return wrapper_function 
     return decorator_function

    def handler(token = None,startswith = None,command = None):
     if token == None:
                   print(Fore.YELLOW+f"You did not specify a keyword (token = ...) in the 'handler' decorator (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (token = ...) в декораторі 'handler'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
     def decorator_function(original_function):
        def wrapper_function():
            msg = message(token)
            text = msg.text
            if startswith is not None:
                word_list = text.split()
                if word_list[0] == startswith:

                        original_function()
                else:
                    pass
            if command != None:
                if text == command:
                        original_function()
                else:
                    pass
        return wrapper_function
     return decorator_function

    def start_command(mod):
          all_functions = inspect.getmembers(mod, inspect.isfunction)
          for key, value in all_functions:
           if str(inspect.signature(value)) == "()":
            value()

    def status(token):
     
     if token == None:
                   print(Fore.YELLOW+f"You did not specify a keyword (token = ...) in the 'status' decorator (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (token = ...) в декораторі 'stataus'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)   
     r = requests.get(f'https://api.telegram.org/bot{token}/getUpdates')
     request = r.json()
     if request == {'ok': True, 'result': []}:
        return "none"
     else:
      return "ok"

    def start(token):
     if token == None:
                   print(Fore.YELLOW+f"You did not specify a keyword (token = ...) in the 'start' decorator (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (token = ...) в декораторі 'start'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)  
     while True:    
       sched = apscheduler.schedulers.background.BackgroundScheduler(job_defaults={'max_instances': 1})
       sched.add_job(status, 'interval', seconds=1/1000,args=[token])
    
    def end_status(token):
       if token == None:
                   print(Fore.YELLOW+f"You did not specify a keyword (token = ...) in the 'end_status' decorator (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (token = ...) в декораторі 'end_status'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)  
       r = requests.get(f'https://api.telegram.org/bot{token}/getUpdates')
       request = r.json()
       requests.get(f'https://api.telegram.org/bot{token}/getUpdates?offset={request["result"][0]["update_id"] + 1}')


    
      




from flask import Flask
from flask import request
from flask import Response
import requests
app = Flask(__name__)
from colorama import init
init()
from colorama import Fore, Back, Style
import sys
import os
import signal
def send_message(bot=None,chat_id=None,text=None,parse_mode=None):
            if bot == None:
                   print(Fore.RED+f"You did not specify a keyword (bot = ...) in the 'send_message' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (bot = ...) в функціі 'send_message'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)

            if chat_id == None:
                   print(Fore.RED+f"You did not specify a keyword (chat_id = ...) in the 'send_message' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (chat_id = ...) в функціі 'send_message'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)
            if text == None:
                   print(Fore.RED+f"You did not specify a keyword (text = ...) in the 'send_message' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (text =  ...)  в функціі 'send_message'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)
            if parse_mode is None:
             url = f'https://api.telegram.org/bot{bot}/sendMessage'
             payload = {
                'chat_id': chat_id,
                'text': text,
                
                }
             r = requests.post(url,json=payload)
             return r
            if parse_mode != None:
              url = f'https://api.telegram.org/bot{bot}/sendMessage'
              payload = {
                'chat_id': chat_id,
                'text': text,
                'parse_mode':parse_mode
                
                }
   
              r = requests.post(url,json=payload)
              return r



import requests
import datetime
import sys
import os
import signal
from colorama import init
init()
from colorama import Fore, Back, Style

class message(object):
  def __init__(self, token):
    if token == None:
                   print(Fore.RED+f"You did not specify a keyword (token = ...) in the 'message' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (token = ...) в функціі 'message'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)
    self.token = token

  @property
  def id(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['message_id']
      except:
        return None
  @property
  def chat_remove_members(self):
      """chat event"""
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['left_chat_participant']
      except:
        return None

  @property
  def edit_(self):
      """edit message handler"""
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['edited_message']['text']
      except:
        return None



  @property
  def chat_new_members(self):#
      """chat event"""
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['new_chat_members']
      except:
        return None
  @property
  def update_id(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()        
       return request["result"][0]['update_id']
      except:
        return None

  @property
  def callback_data(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['callback_query']['data']
      except:
        return None

  @property
  def callback_message_id(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['callback_query']['message']['message_id']
      except:
        return None

  @property
  def callback(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['callback_query']
      except:
        return None

  @property
  def message(self):#
      r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
      request = r.json()
      try:
       return request["result"][0]['message']
      except:
        return None
  @property
  def callback_author_username(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['callback_query']['from']['username']
      except:
        return None

  @property
  def callback_id(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['callback_query']['id']
      except:
        return None

  @property
  def callback_chat(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['callback_query']['message']['chat']['id']
      except:
        return None

  @property
  def author_id(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['from']['id']
      except:
        return None
  @property
  def author_username(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['from']['username']
      except:
        return None
  @property
  def author_first_name(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['from']['first_name']
      except:
        return None
  @property
  def text(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['text']
      except :
        return None

  @property
  def author_is_bot(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['from']['is_bot']
      except:
        return None

  @property
  def chat_id(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['chat']['id']
      except:
       return None

  @property
  def language(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['from']['language_code']
      except:
       return None

  @property
  def reply_message(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['reply_to_message']
      except:
        return None

  @property
  def reply_message_id(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['reply_to_message']['message_id']
      except:
        return None

  @property
  def reply_message_author_username(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['reply_to_message']['from']['username']
      except:
        return None

  @property
  def reply_message_author_is_bot(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['reply_to_message']['from']['is_bot']
      except:
        return None

  @property
  def reply_message_first_name(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['reply_to_message']['from']['first_name']
      except:
        return None



  @property
  def reply_message_text(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['reply_to_message']['text']
      except:
        return None

  @property
  def date(self):
      try:
       r = requests.get(f'https://api.telegram.org/bot{self.token}/getUpdates')
       request = r.json()
       return request["result"][0]['message']['date']
      except:
        return None


from .send import send_message
from .reply import reply_message
from .edit import edit_message
from .delete import delete_message
from .button import buttons,answer_callback,callback,callback_edit
from .sticker import send_sticker
from .photo import send_photo



import requests
from .send import send_message
from .edit import edit_message
from colorama import init
init()
from colorama import Fore, Back, Style
import sys
import os
import signal


def buttons(bot=None,chat_id=None,button=None,text=None):
            if bot == None:
                   print(Fore.RED+f"You did not specify a keyword (bot = ...) in the 'buttons' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (bot = ...) в функціі 'buttons'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)
              
            if button == None:
                   print(Fore.RED+f"You did not specify a keyword (button = ...) in the 'buttons' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (button = ...) в функціі 'buttons'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)

            if chat_id == None:
                   print(Fore.RED+f"You did not specify a keyword (chat_id = ...) in the 'button' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (chat_id = ...) в функціі 'button'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)
            url = f'https://api.telegram.org/bot{bot}/sendMessage'
            payload = {
                'chat_id': chat_id,
                'text': text,
                "reply_markup": button
                }

            r = requests.post(url,json=payload)
            return r

def answer_callback(bot=None,msg=None,data=None,text=None,show_alters=False):
            if bot == None:
                   print(Fore.RED+f"You did not specify a keyword (bot = ...) in the 'buttons' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (bot = ...) в функціі 'buttons'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)
              
            if msg == None:
                   print(Fore.RED+f"You did not specify a keyword (msg = ...) in the 'answer_callback' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (msg = ...) в функціі 'answer_callback'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)

            if data == None:
                   print(Fore.RED+f"You did not specify a keyword (data = ...) in the 'answer_callback' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (data = ...) в функціі 'answer_callback'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)
            if text == None:
                   print(Fore.RED+f"You did not specify a keyword (text = ...) in the 'answer_callback' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (text = ...) в функціі 'answer_callback'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)

            url = f'https://api.telegram.org/bot{bot}/sendMessage'
            if data == msg.callback_data:
             print("test")
             url = f' https://api.telegram.org/bot{bot}/answercallbackquery'
             payload = {
                
                         "callback_query_id":f"{msg.callback_id}",
                         "text":text,
                         "show_alert":show_alters,
                      }

                
             r = requests.post(url,json=payload)
             return r
            if data != msg.callback_data:
             pass


def callback_edit(bot,data=None,data_json=None,text=None,button={}):
            if bot == None:
                   print(Fore.RED+f"You did not specify a keyword (bot = ...) in the 'callback_edit' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (bot = ...) в функціі 'callback_edit'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)
              
            if data_json == None:
                   print(Fore.RED+f"You did not specify a keyword (data_json = ...) in the 'callback_edit' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (data_json = ...) в функціі 'callback_edit'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)

            if data == None:
                   print(Fore.RED+f"You did not specify a keyword (data = ...) in the 'callback_edit' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (data = ...) в функціі 'callback_edit'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)
            if text == None:
                   print(Fore.RED+f"You did not specify a keyword (text = ...) in the 'callback_edit' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (text = ...) в функціі 'callback_edit'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)
            if data == data_json.callback_data:
             url = f' https://api.telegram.org/bot{bot}/answercallbackquery'
             payload = {
                
  "callback_query_id":data_json.callback_id,
               }

                
             r = requests.post(url,json=payload)
             edit_message(bot,chat_id=data_json.callback_chat,msg_id=data_json.callback_message_id,text=f"{text}",button=button)#send message\{}
def callback(bot,data=None,data_json=None,text=None):
            if bot == None:
                   print(Fore.RED+f"You did not specify a keyword (bot = ...) in the 'callback' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (bot = ...) в функціі 'callback'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)
              
            if data_json == None:
                   print(Fore.RED+f"You did not specify a keyword (data_json = ...) in the 'callback' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (data_json = ...) в функціі 'callback'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)

            if data == None:
                   print(Fore.RED+f"You did not specify a keyword (data = ...) in the 'callback' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (data = ...) в функціі 'callback'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)
            if text == None:
                   print(Fore.RED+f"You did not specify a keyword (text = ...) in the 'callback' function (line : {sys._getframe(1).f_lineno})"+Style.RESET_ALL)  
                   print(Fore.RED+f"Ви не вказали ключове слово (text = ...) в функціі 'callback'  (лінія :{sys._getframe(1).f_lineno})"+Style.RESET_ALL)
                   sig = getattr(signal, "SIGKILL", signal.SIGTERM)
                   os.kill(os.getpid(), sig)
            if data == data_json.callback_data:
             url = f' https://api.telegram.org/bot{bot}/answercallbackquery'
             payload = {
                
  "callback_query_id":data_json.callback_id,
              }

                
             r = requests.post(url,json=payload)
             send_message(bot,chat_id=data_json.callback_chat,text=f"{text}",parse_mode='HTML')#send message\{}
  

            




import requests
from colorama import init
init()
from colorama import Fore, Back, Style
from os import path
from PIL import Image,ImageFilter 
import subprocess
import sys
import fileinput



def send_photo(bot=None,chat_id=None,photo=None):
            url = f'https://api.telegram.org/bot{bot}/sendPhoto'
            payload = {
                'chat_id': chat_id,
                'photo' : fileinput.input(files=open('D:/Desktop/bonfire-discord-libraly/obama.png', 'rb'))
                }


            r = requests.post(url,json=payload,)
            return r